@@ -30,7 +30,7 @@ public:
 
 protected:
   db_connection()
-    : m_db(QSqlDatabase::addDatabase("QSQLITE"))
+    : m_db(QSqlDatabase::addDatabase(u"QSQLITE"_qs))
   {}
 
   ~db_connection()
@@ -51,14 +51,13 @@ public:
     , m_table(table)
   {
     if (!db.tables().contains(table)) {
-      db.exec(QString(
-                "CREATE TABLE '%1' ("
-                "    'id'      INTEGER PRIMARY KEY,"
-                "    'ip'      TEXT NOT NULL UNIQUE,"
-                "    'client'  TEXT NOT NULL,"
-                "    'pid'     BLOB NOT NULL,"
-                "    'tag'     TEXT"
-                ");").arg(table));
+      db.exec(u"CREATE TABLE '%1' ("
+              u"    'id'      INTEGER PRIMARY KEY,"
+              u"    'ip'      TEXT NOT NULL UNIQUE,"
+              u"    'client'  TEXT NOT NULL,"
+              u"    'pid'     BLOB NOT NULL,"
+              u"    'tag'     TEXT"
+              u");"_qs.arg(table));
       db.commit();
     }
   }
@@ -66,7 +65,7 @@ public:
   bool log_peer(const lt::peer_info& info, const std::string& tag = {})
   {
     QSqlQuery q(m_db);
-    q.prepare(QString("INSERT INTO '%1' (ip, client, pid, tag) VALUES (?, ?, ?, ?)").arg(m_table));
+    q.prepare(u"INSERT INTO '%1' (ip, client, pid, tag) VALUES (?, ?, ?, ?)"_qs.arg(m_table));
     q.addBindValue(QString::fromStdString(info.ip.address().to_string()));
     q.addBindValue(QString::fromStdString(info.client));
     q.addBindValue(QString::fromLatin1(info.pid.data(), 8));
